import { Compiler, WebpackPluginInstance } from 'webpack';
declare enum AdditionalBeforeSaveHookNames {
    beforeCreate = "beforeCreate",
    beforeUpdate = "beforeUpdate"
}
declare enum AdditionalAfterSaveHookNames {
    afterCreate = "afterCreate",
    afterUpdate = "afterUpdate"
}
declare enum CronHookNames {
    hourly = "hourly",
    daily = "daily",
    weekly = "weekly",
    monthly = "monthly",
    datetime = "datetime"
}
declare enum ParseServiceSchemaFieldType {
    String = "String",
    ACL = "ACL",
    Date = "Date",
    Relation = "Relation",
    Pointer = "Pointer",
    Object = "Object",
    Array = "Array",
    Boolean = "Boolean"
}
declare type ParseFunctionServiceSchemaFieldRelationType = {
    type: ParseServiceSchemaFieldType.Pointer | ParseServiceSchemaFieldType.Relation;
    targetClass: string;
    required?: boolean;
};
declare type ParseFunctionServiceSchemaFieldType = {
    type: ParseServiceSchemaFieldType;
    targetClass: string;
    required?: boolean;
};
declare type ParseFunctionServiceSchemaField = ParseFunctionServiceSchemaFieldRelationType | ParseFunctionServiceSchemaFieldType;
interface ParseFunctionPluginOptions {
    functionDirectory: string;
    moduleAlias: string;
}
export declare class ParseFunctionsPlugin implements WebpackPluginInstance {
    options: ParseFunctionPluginOptions;
    basePath?: string;
    buildPath?: string;
    schemaPaths?: string[];
    indexFilePath?: string;
    get templateHelpers(): {
        SubhooksMap: {
            beforeSave: AdditionalBeforeSaveHookNames[];
            afterSave: AdditionalAfterSaveHookNames[];
            beforeDelete: never[];
            afterDelete: never[];
        };
        CronHookNames: typeof CronHookNames;
        AdditionalHookNames: {
            beforeCreate: AdditionalBeforeSaveHookNames.beforeCreate;
            beforeUpdate: AdditionalBeforeSaveHookNames.beforeUpdate;
            afterCreate: AdditionalAfterSaveHookNames.afterCreate;
            afterUpdate: AdditionalAfterSaveHookNames.afterUpdate;
        };
        removeExtension: typeof removeExtension;
        mapSchemaTypeToTSType: typeof mapSchemaTypeToTSType;
        createImportFromFilename: typeof createImportFromFilename;
        getSanitizedFunctionName: typeof getSanitizedFunctionName;
    };
    constructor(opts?: Partial<ParseFunctionPluginOptions>);
    apply(compiler: Compiler): Promise<void>;
    private startBuild;
    private makeHelpersFile;
    private makeTypesFile;
    private makeServiceIndexFile;
    private makeServiceFile;
}
declare function removeExtension(filePath: string): string;
declare function createImportFromFilename(filePath: string, prefix?: string, basePath?: string): string;
declare function getSanitizedFunctionName(filePath: string, prefix?: string): string;
declare function mapSchemaTypeToTSType(schemaField: ParseFunctionServiceSchemaField): string;
export default ParseFunctionsPlugin;
